@@ -178,8 +178,10 @@ class _Datasource(_Base):
         self.key = key
         self.trainers = {}
 
-    def add_trainer(self, key, train_callback, test_callback, default_hyper_params={} , description=None, model_path=None):
-        params = {'key': key , "defaultHyperParams": default_hyper_params}
+    def add_trainer(self, key, train_callback, test_callback, default_hyper_params=None, description=None, model_path=None):
+        params = {'key': key}
+        if default_hyper_params is not None:
+            params['defaultHyperParams'] = default_hyper_params
         if description is not None:
             params['description'] = description
         self._make_request('POST', f'/datasources/{self.key}/trainers', params=params)
@@ -322,11 +324,13 @@ class DynamoFL(_Base):
         # Test
         if not yes_stats:
             print(f'>>> ({project_key}-{datasource_key}) Running validation on round ({prev_round}) federated model...')
-            scores, num_samples = test(datasource_key, federated_model_path, project_info)
-            print(scores)
-            print(f'>>> ({project_key}-{datasource_key}) Uploading scores...')
-            project.report_stats(scores, num_samples, prev_round, datasource_key)
-            print('Done.')
+            test_res = test(datasource_key, federated_model_path, project_info)
+            if test_res is not None:
+                scores, num_samples = test_res
+                print(scores)
+                print(f'>>> ({project_key}-{datasource_key}) Uploading scores...')
+                project.report_stats(scores, num_samples, prev_round, datasource_key)
+                print('Done.')
             print()
 
         # Train and push
